@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,11 +23,12 @@
 
 namespace KSieveUi
 {
+class SieveEditorGraphicalModeWidget;
 class SelectMatchTypeComboBox : public KComboBox
 {
     Q_OBJECT
 public:
-    explicit SelectMatchTypeComboBox(QWidget *parent = Q_NULLPTR);
+    explicit SelectMatchTypeComboBox(KSieveUi::SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QWidget *parent = nullptr);
     ~SelectMatchTypeComboBox();
 
     QString code(bool &negative) const;
