@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,21 +24,18 @@
 class QDomElement;
 namespace KSieveUi
 {
+class SieveImapAccountSettings;
+class SieveEditorGraphicalModeWidget;
 class SieveAction : public QObject
 {
     Q_OBJECT
 public:
-    SieveAction(const QString &name, const QString &label, QObject *parent = Q_NULLPTR);
+    SieveAction(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, const QString &name, const QString &label, QObject *parent = nullptr);
     virtual ~SieveAction();
 
     QString name() const;
     QString label() const;
 
-    /**
-     * Static function that creates a filter action of this type.
-     */
-    static SieveAction *newAction();
-
     virtual QWidget *createParamWidget(QWidget *parent) const;
 
     virtual bool setParamWidgetValue(const QDomElement &element, QWidget *parent, QString &error);
@@ -63,6 +60,11 @@ public:
     void tooManyArgument(const QString &tagName, int index, int maxValue, QString &error);
     void serverDoesNotSupportFeatures(const QString &feature, QString &error);
 
+protected:
+    SieveImapAccountSettings sieveImapAccountSettings() const;
+    QStringList sieveCapabilities() const;
+    SieveEditorGraphicalModeWidget *mSieveGraphicalModeWidget;
+
 Q_SIGNALS:
     void valueChanged();
 
