@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -31,16 +31,11 @@
 
 using namespace KSieveUi;
 
-SieveActionAddHeader::SieveActionAddHeader(QObject *parent)
-    : SieveActionAbstractEditHeader(QStringLiteral("addheader"), i18n("Add header"), parent)
+SieveActionAddHeader::SieveActionAddHeader(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
+    : SieveActionAbstractEditHeader(sieveGraphicalModeWidget, QStringLiteral("addheader"), i18n("Add header"), parent)
 {
 }
 
-SieveAction *SieveActionAddHeader::newAction()
-{
-    return new SieveActionAddHeader;
-}
-
 QWidget *SieveActionAddHeader::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
