@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -32,16 +32,11 @@
 
 using namespace KSieveUi;
 
-SieveActionDeleteHeader::SieveActionDeleteHeader(QObject *parent)
-    : SieveActionAbstractEditHeader(QStringLiteral("deleteheader"), i18n("Delete header"), parent)
+SieveActionDeleteHeader::SieveActionDeleteHeader(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
+    : SieveActionAbstractEditHeader(sieveGraphicalModeWidget, QStringLiteral("deleteheader"), i18n("Delete header"), parent)
 {
 }
 
-SieveAction *SieveActionDeleteHeader::newAction()
-{
-    return new SieveActionDeleteHeader;
-}
-
 QWidget *SieveActionDeleteHeader::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
@@ -49,7 +44,7 @@ QWidget *SieveActionDeleteHeader::createParamWidget(QWidget *parent) const
     grid->setMargin(0);
     w->setLayout(grid);
 
-    SelectMatchTypeComboBox *matchType = new SelectMatchTypeComboBox;
+    SelectMatchTypeComboBox *matchType = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
     matchType->setObjectName(QStringLiteral("matchtype"));
     connect(matchType, &SelectMatchTypeComboBox::valueChanged, this, &SieveActionDeleteHeader::valueChanged);
     grid->addWidget(matchType, 0, 0);
