@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,9 +24,10 @@
 namespace KSieveUi
 {
 class SieveAction;
+class SieveEditorGraphicalModeWidget;
 namespace SieveActionList
 {
-QList<KSieveUi::SieveAction *> actionList();
+QList<KSieveUi::SieveAction *> actionList(KSieveUi::SieveEditorGraphicalModeWidget *graphicalModeWidget);
 }
 }
 
