@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -31,16 +31,11 @@
 
 using namespace KSieveUi;
 
-SieveActionNotify::SieveActionNotify(QObject *parent)
-    : SieveAction(QStringLiteral("notify"), i18n("Notify"), parent)
+SieveActionNotify::SieveActionNotify(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
+    : SieveAction(sieveGraphicalModeWidget, QStringLiteral("notify"), i18n("Notify"), parent)
 {
 }
 
-SieveAction *SieveActionNotify::newAction()
-{
-    return new SieveActionNotify;
-}
-
 QWidget *SieveActionNotify::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
@@ -126,12 +121,12 @@ QString SieveActionNotify::code(QWidget *w) const
     const QLineEdit *message = w->findChild<QLineEdit *>(QStringLiteral("message"));
     const QString messageStr = message->text();
     if (!messageStr.isEmpty()) {
-        result += QStringLiteral(" :message \"%2\"").arg(messageStr);
+        result += QStringLiteral(" :message \"%1\"").arg(messageStr);
     }
 
     const QLineEdit *method = w->findChild<QLineEdit *>(QStringLiteral("method"));
     const QString methodStr = method->text();
-    result += QStringLiteral(" \"%3\";").arg(methodStr);
+    result += QStringLiteral(" \"%1\";").arg(methodStr);
 
     return result;
 }
