@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,16 +29,11 @@
 #include "libksieve_debug.h"
 
 using namespace KSieveUi;
-SieveActionReject::SieveActionReject(QObject *parent)
-    : SieveAction(QStringLiteral("reject"), i18n("Reject"), parent)
+SieveActionReject::SieveActionReject(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
+    : SieveAction(sieveGraphicalModeWidget, QStringLiteral("reject"), i18n("Reject"), parent)
 {
 }
 
-SieveAction *SieveActionReject::newAction()
-{
-    return new SieveActionReject;
-}
-
 QWidget *SieveActionReject::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
