@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -34,15 +34,10 @@
 
 using namespace KSieveUi;
 
-SieveActionVacation::SieveActionVacation(QObject *parent)
-    : SieveAction(QStringLiteral("vacation"), i18n("Vacation"), parent)
+SieveActionVacation::SieveActionVacation(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
+    : SieveAction(sieveGraphicalModeWidget, QStringLiteral("vacation"), i18n("Vacation"), parent)
 {
-    mHasVacationSecondsSupport = SieveEditorGraphicalModeWidget::sieveCapabilities().contains(QStringLiteral("vacation-seconds"));
-}
-
-SieveAction *SieveActionVacation::newAction()
-{
-    return new SieveActionVacation;
+    mHasVacationSecondsSupport = sieveCapabilities().contains(QStringLiteral("vacation-seconds"));
 }
 
 QWidget *SieveActionVacation::createParamWidget(QWidget *parent) const
@@ -52,7 +47,7 @@ QWidget *SieveActionVacation::createParamWidget(QWidget *parent) const
     grid->setMargin(0);
     w->setLayout(grid);
 
-    QLabel *lab = Q_NULLPTR;
+    QLabel *lab = nullptr;
     if (mHasVacationSecondsSupport) {
         SelectVacationComboBox *vacation = new SelectVacationComboBox;
         vacation->setObjectName(QStringLiteral("vacationcombobox"));
