@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,7 +26,7 @@ class SelectAddHeaderPositionCombobox : public KComboBox
 {
     Q_OBJECT
 public:
-    explicit SelectAddHeaderPositionCombobox(QWidget *parent = Q_NULLPTR);
+    explicit SelectAddHeaderPositionCombobox(QWidget *parent = nullptr);
     ~SelectAddHeaderPositionCombobox();
 
     QString code() const;
