@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,11 +25,12 @@
 class QDomElement;
 namespace KSieveUi
 {
+class SieveEditorGraphicalModeWidget;
 class SieveCondition : public QObject
 {
     Q_OBJECT
 public:
-    SieveCondition(const QString &name, const QString &label, QObject *parent = Q_NULLPTR);
+    SieveCondition(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, const QString &name, const QString &label, QObject *parent = nullptr);
     virtual ~SieveCondition();
 
     QString name() const;
@@ -60,6 +61,10 @@ public:
     void tooManyArgument(const QString &tagName, int index, int maxValue, QString &error);
     void serverDoesNotSupportFeatures(const QString &feature, QString &error);
 
+protected:
+    QStringList sieveCapabilities() const;
+    SieveEditorGraphicalModeWidget *mSieveGraphicalModeWidget;
+
 Q_SIGNALS:
     void valueChanged();
 
