@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -33,16 +33,11 @@
 
 using namespace KSieveUi;
 
-SieveConditionAddress::SieveConditionAddress(QObject *parent)
-    : SieveCondition(QStringLiteral("address"), i18n("Address"), parent)
+SieveConditionAddress::SieveConditionAddress(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
+    : SieveCondition(sieveGraphicalModeWidget, QStringLiteral("address"), i18n("Address"), parent)
 {
 }
 
-SieveCondition *SieveConditionAddress::newAction()
-{
-    return new SieveConditionAddress;
-}
-
 QWidget *SieveConditionAddress::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
@@ -50,7 +45,7 @@ QWidget *SieveConditionAddress::createParamWidget(QWidget *parent) const
     lay->setMargin(0);
     w->setLayout(lay);
 
-    SelectAddressPartComboBox *selectAddressPart = new SelectAddressPartComboBox;
+    SelectAddressPartComboBox *selectAddressPart = new SelectAddressPartComboBox(mSieveGraphicalModeWidget);
     connect(selectAddressPart, &SelectAddressPartComboBox::valueChanged, this, &SieveConditionAddress::valueChanged);
     selectAddressPart->setObjectName(QStringLiteral("addresspartcombobox"));
     lay->addWidget(selectAddressPart);
@@ -58,7 +53,7 @@ QWidget *SieveConditionAddress::createParamWidget(QWidget *parent) const
     QGridLayout *grid = new QGridLayout;
     grid->setMargin(0);
     lay->addLayout(grid);
-    SelectMatchTypeComboBox *selectMatchCombobox = new SelectMatchTypeComboBox;
+    SelectMatchTypeComboBox *selectMatchCombobox = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
     connect(selectMatchCombobox, &SelectMatchTypeComboBox::valueChanged, this, &SieveConditionAddress::valueChanged);
     selectMatchCombobox->setObjectName(QStringLiteral("matchtypecombobox"));
     grid->addWidget(selectMatchCombobox, 0, 0);
@@ -94,7 +89,7 @@ QString SieveConditionAddress::code(QWidget *w) const
 
     const QLineEdit *edit = w->findChild<QLineEdit *>(QStringLiteral("editaddress"));
     const QString addressStr = AutoCreateScriptUtil::createAddressList(edit->text().trimmed(), false);
-    return AutoCreateScriptUtil::negativeString(isNegative) + QStringLiteral("address %1 %2 %3 %4").arg(selectAddressPartStr).arg(matchTypeStr).arg(selectHeaderTypeStr).arg(addressStr);
+    return AutoCreateScriptUtil::negativeString(isNegative) + QStringLiteral("address %1 %2 %3 %4").arg(selectAddressPartStr, matchTypeStr, selectHeaderTypeStr, addressStr);
 }
 
 QStringList SieveConditionAddress::needRequires(QWidget *w) const
