@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -31,16 +31,11 @@
 #include <QGridLayout>
 
 using namespace KSieveUi;
-SieveConditionEnvironment::SieveConditionEnvironment(QObject *parent)
-    : SieveCondition(QStringLiteral("environment"), i18n("Environment"), parent)
+SieveConditionEnvironment::SieveConditionEnvironment(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
+    : SieveCondition(sieveGraphicalModeWidget, QStringLiteral("environment"), i18n("Environment"), parent)
 {
 }
 
-SieveCondition *SieveConditionEnvironment::newAction()
-{
-    return new SieveConditionEnvironment;
-}
-
 QWidget *SieveConditionEnvironment::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
