@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -27,10 +27,7 @@ class SieveConditionFalse : public SieveCondition
 {
     Q_OBJECT
 public:
-    explicit SieveConditionFalse(QObject *parent = Q_NULLPTR);
-
-    static SieveCondition *newAction();
-
+    explicit SieveConditionFalse(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent = nullptr);
     QWidget *createParamWidget(QWidget *parent) const Q_DECL_OVERRIDE;
 
     QString code(QWidget *w) const Q_DECL_OVERRIDE;
