@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,11 +23,12 @@
 #include <QComboBox>
 namespace KSieveUi
 {
+class SieveEditorGraphicalModeWidget;
 class SelectComparatorComboBox : public QComboBox
 {
     Q_OBJECT
 public:
-    explicit SelectComparatorComboBox(QWidget *parent = Q_NULLPTR);
+    explicit SelectComparatorComboBox(KSieveUi::SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QWidget *parent = nullptr);
     ~SelectComparatorComboBox();
 
     QString code() const;
@@ -38,7 +39,7 @@ public:
 Q_SIGNALS:
     void valueChanged();
 private:
-    void initialize();
+    void initialize(const QStringList &sieveCapabilities);
 };
 }
 #endif // SELECTCOMPARATORCOMBOBOX_H
