@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -34,8 +34,8 @@
 #include <QDomNode>
 #include "libksieve_debug.h"
 
-namespace KSieveUi
-{
+using namespace KSieveUi;
+
 SieveForEveryPartWidget::SieveForEveryPartWidget(QWidget *parent)
     : SieveWidgetPageAbstract(parent)
 {
@@ -115,5 +115,4 @@ void SieveForEveryPartWidget::loadScript(const QDomElement &element, QString &er
         }
     }
 }
-}
 
