@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -33,6 +33,7 @@ namespace KSieveUi
 {
 class SieveConditionWidgetLister;
 class SieveActionWidgetLister;
+class SieveEditorGraphicalModeWidget;
 
 class SieveScriptBlockWidget : public SieveWidgetPageAbstract
 {
@@ -44,7 +45,7 @@ public:
         AllCondition
     };
 
-    explicit SieveScriptBlockWidget(QWidget *parent = Q_NULLPTR);
+    explicit SieveScriptBlockWidget(SieveEditorGraphicalModeWidget *graphicalModeWidget, QWidget *parent = nullptr);
     ~SieveScriptBlockWidget();
 
     void setPageType(PageType type) Q_DECL_OVERRIDE;
@@ -67,6 +68,7 @@ private:
     void updateCondition();
     MatchCondition mMatchCondition;
     QGroupBox *mConditions;
+    SieveEditorGraphicalModeWidget *mSieveGraphicalModeWidget;
     SieveConditionWidgetLister *mScriptConditionLister;
     SieveActionWidgetLister *mScriptActionLister;
     QRadioButton *mMatchAll;
