@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -32,7 +32,7 @@ class SieveScriptDescriptionDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit SieveScriptDescriptionDialog(QWidget *parent = Q_NULLPTR);
+    explicit SieveScriptDescriptionDialog(QWidget *parent = nullptr);
     ~SieveScriptDescriptionDialog();
 
     void setDescription(const QString &desc);
