@@ -14,12 +14,14 @@
 #include "sievedebugdialog.h"
 #include "kpimtextedit/plaintexteditorwidget.h"
 #include "kpimtextedit/plaintexteditor.h"
+#include "util/util_p.h"
 
-#include <agentinstance.h>
 #include "libksieve_debug.h"
 #include <KLocalizedString>
 #include <kmanagesieve/sievejob.h>
-#include <ksieveui/util.h>
+#include <KSyntaxHighlighting/SyntaxHighlighter>
+#include <KSyntaxHighlighting/Definition>
+#include <KSyntaxHighlighting/Theme>
 
 #include <QTimer>
 #include <KSharedConfig>
@@ -32,21 +34,26 @@ using namespace KSieveUi;
 
 SieveDebugDialog::SieveDebugDialog(QWidget *parent)
     : QDialog(parent),
-      mSieveJob(Q_NULLPTR),
-      mShutDownJob(Q_NULLPTR)
+      mSieveJob(nullptr),
+      mShutDownJob(nullptr)
 {
     setWindowTitle(i18n("Sieve Diagnostics"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
     // Collect all accounts
-    const Akonadi::AgentInstance::List lst = KSieveUi::Util::imapAgentInstances();
-    mResourceIdentifier.reserve(lst.count());
-    foreach (const Akonadi::AgentInstance &type, lst) {
-        mResourceIdentifier << type.identifier();
-    }
+    mResourceIdentifier = KSieveUi::Util::sieveImapResourceNames();
 
     mEdit = new KPIMTextEdit::PlainTextEditorWidget(this);
     mEdit->setReadOnly(true);
+    KSyntaxHighlighting::Definition def;
+    def = mRepo.definitionForName(QStringLiteral("Sieve"));
+
+    KSyntaxHighlighting::SyntaxHighlighter *hl = new KSyntaxHighlighting::SyntaxHighlighter(mEdit->editor()->document());
+    hl->setTheme((palette().color(QPalette::Base).lightness() < 128)
+                 ? mRepo.defaultTheme(KSyntaxHighlighting::Repository::DarkTheme)
+                 : mRepo.defaultTheme(KSyntaxHighlighting::Repository::LightTheme));
+    hl->setDefinition(def);
+
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &SieveDebugDialog::reject);
 
@@ -66,7 +73,7 @@ SieveDebugDialog::~SieveDebugDialog()
 {
     if (mSieveJob) {
         mSieveJob->kill();
-        mSieveJob = Q_NULLPTR;
+        mSieveJob = nullptr;
     }
     qCDebug(LIBKSIEVE_LOG);
     writeConfig();
@@ -91,7 +98,7 @@ void SieveDebugDialog::slotShutDownJob()
 {
     disconnect(mSieveJob, &KManageSieve::SieveJob::gotList, this, &SieveDebugDialog::slotGetScriptList);
     mSieveJob->kill();
-    mSieveJob = Q_NULLPTR;
+    mSieveJob = nullptr;
     mEdit->editor()->appendPlainText(i18n("Unable to get the info\n\n"));
     mResourceIdentifier.pop_front();
     QTimer::singleShot(0, this, &SieveDebugDialog::slotDiagNextAccount);
@@ -114,7 +121,8 @@ void SieveDebugDialog::slotDiagNextAccount()
     mEdit->editor()->appendPlainText(i18n("------------------------------------------------------------\n"));
 
     // Detect URL for this IMAP account
-    const QUrl url = KSieveUi::Util::findSieveUrlForAccount(ident);
+    const KSieveUi::Util::AccountInfo info = KSieveUi::Util::fullAccountInfo(ident);
+    const QUrl url  = info.sieveUrl;
     if (!url.isValid()) {
         mEdit->editor()->appendPlainText(i18n("(Account does not support Sieve)\n\n"));
     } else {
@@ -122,6 +130,8 @@ void SieveDebugDialog::slotDiagNextAccount()
 
         mSieveJob = KManageSieve::SieveJob::list(mUrl);
 
+        //Laurent: not necessary as it's a readonly dialog
+        //mSieveJob->setProperty("sieveimapaccountsettings", QVariant::fromValue(info.sieveImapAccountSettings));
         connect(mSieveJob, &KManageSieve::SieveJob::gotList, this, &SieveDebugDialog::slotGetScriptList);
 
         // Bypass the singleShot timer -- it's fired when we get our data
@@ -148,7 +158,8 @@ void SieveDebugDialog::slotDiagNextScript()
 
     mEdit->editor()->appendPlainText(i18n("Contents of script '%1':\n", scriptFile));
 
-    mUrl = KSieveUi::Util::findSieveUrlForAccount(mResourceIdentifier.first());
+    const KSieveUi::Util::AccountInfo info = KSieveUi::Util::fullAccountInfo(mResourceIdentifier.first());
+    mUrl  = info.sieveUrl;
 
     mUrl = mUrl.adjusted(QUrl::RemoveFilename);
     mUrl.setPath(mUrl.path() + scriptFile);
@@ -165,7 +176,7 @@ void SieveDebugDialog::slotGetScript(KManageSieve::SieveJob *job, bool success,
                            << ", ?," << active << ")" << endl
                            << "script:" << endl
                            << script;
-    mSieveJob = Q_NULLPTR; // job deletes itself after returning from this slot!
+    mSieveJob = nullptr; // job deletes itself after returning from this slot!
 
     if (!success) {
         mEdit->editor()->appendPlainText(i18n("Retrieving the script failed.\n"
@@ -189,9 +200,9 @@ void SieveDebugDialog::slotGetScriptList(KManageSieve::SieveJob *job, bool succe
     if (mShutDownJob->isActive()) {
         mShutDownJob->stop();
     }
-    qCDebug(LIBKSIEVE_LOG) << "Success:" << success << ", List:" << scriptList.join(QStringLiteral(",")) <<
+    qCDebug(LIBKSIEVE_LOG) << "Success:" << success << ", List:" << scriptList.join(QLatin1Char(',')) <<
                            ", active:" << activeScript;
-    mSieveJob = Q_NULLPTR; // job deletes itself after returning from this slot!
+    mSieveJob = nullptr; // job deletes itself after returning from this slot!
 
     mEdit->editor()->appendPlainText(i18n("Sieve capabilities:\n"));
     const QStringList caps = job->sieveCapabilities();
