@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -19,7 +19,7 @@
 
 #include "parsingresultdialog.h"
 #include "xmlprintingsyntaxhighlighter.h"
-#include "PimCommon/PimUtil"
+#include <PimCommon/PimUtil>
 #include "kpimtextedit/plaintexteditorwidget.h"
 #include "kpimtextedit/plaintexteditor.h"
 
@@ -36,7 +36,7 @@ ParsingResultDialog::ParsingResultDialog(QWidget *parent)
     : QDialog(parent)
 {
     setWindowTitle(i18n("Sieve Parsing"));
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
 
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     QPushButton *user1Button = new QPushButton(this);
