@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -18,7 +18,7 @@
 */
 #ifndef PARSINGRESULTDIALOG_H
 #define PARSINGRESULTDIALOG_H
-#include "ksieveui_export.h"
+#include "ksieveui_private_export.h"
 #include <QDialog>
 
 namespace KPIMTextEdit
@@ -27,11 +27,11 @@ class PlainTextEditorWidget;
 }
 namespace KSieveUi
 {
-class KSIEVEUI_EXPORT ParsingResultDialog : public QDialog
+class KSIEVEUI_TESTS_EXPORT ParsingResultDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit ParsingResultDialog(QWidget *parent = Q_NULLPTR);
+    explicit ParsingResultDialog(QWidget *parent = nullptr);
     ~ParsingResultDialog();
 
     void setResultParsing(const QString &result);
