@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -43,7 +43,7 @@ using namespace KSieveUi;
 
 SieveScriptDebuggerFrontEndWidget::SieveScriptDebuggerFrontEndWidget(QWidget *parent)
     : QWidget(parent),
-      mProcess(Q_NULLPTR)
+      mProcess(nullptr)
 {
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mainLayout->setMargin(0);
@@ -51,7 +51,7 @@ SieveScriptDebuggerFrontEndWidget::SieveScriptDebuggerFrontEndWidget(QWidget *pa
     QFormLayout *formLayout = new QFormLayout;
     mainLayout->addLayout(formLayout);
 
-    QLabel *emailLab = new QLabel(i18n("Email path:"));
+    QLabel *emailLab = new QLabel(i18n("Email path:"), this);
     emailLab->setObjectName(QStringLiteral("emaillab"));
 
     mEmailPath = new KUrlRequester(this);
@@ -184,7 +184,7 @@ void SieveScriptDebuggerFrontEndWidget::slotDebugScript()
     mSieveTestResult->editor()->appendPlainText(QStringLiteral("\n"));
     if (!mProcess->waitForStarted()) {
         delete mProcess;
-        mProcess = 0;
+        mProcess = nullptr;
         mDebugScript->setEnabled(true);
     }
 }
@@ -204,7 +204,7 @@ void SieveScriptDebuggerFrontEndWidget::slotReadErrorOutput()
 void SieveScriptDebuggerFrontEndWidget::slotDebugFinished()
 {
     delete mProcess;
-    mProcess = 0;
+    mProcess = nullptr;
     mDebugScript->setEnabled(true);
 }
 
